(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    165470,       6954]*)
(*NotebookOutlinePosition[    166267,       6982]*)
(*  CellTagsIndexPosition[    166223,       6978]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Generalized Hanoi Tower", "Title",
  FontColor->RGBColor[0, 0.501961, 0.752941],
  Background->RGBColor[1, 1, 0.501961]],

Cell["by Jaime Rangel-Mondrag\[OAcute]n", "Author",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Autonomous University of Queretaro. Faculty of Informatics
Queretaro\.b4s Institute of Technology. Mechatronics Department

jrangel@sunserver.uaq.mx\
\>", "Address"],

Cell["\<\


Copyright \[Copyright] May 2003
Permission is hereby granted to reproduce part or all of this file for any \
purpose other than direct profit providing that the source is acknowledged.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Introduction", "SectionFirst"],

Cell["\<\
Every truth has four corners. As a teacher, I give you one corner. 
It is for you to find the other three.
- Confusius

The significant problems we face cannot be solved at the same level of \
thinking we were at when we created them. 
  - Albert Einstein\
\>", "Reference",
  TextAlignment->Right,
  TextJustification->0],

Cell["\<\
The problem of the tower of Hanoi has become a classic one appearing in most \
introductory courses on algorithm analysis and design. In its full generality \
it considers a tower of disks of decreasing size (the largest one at the \
bottom) being stacked initially in a peg. Other pegs are provided so that \
they can be used in following certain rules aimed at transferring the tower \
from its initial peg to a different one. The rules establish that a disk has \
to be moved in such a way that it is transferred on top of a bigger disk or \
to an empty peg. So, by moving one disk at a time, the question arises as to \
how to transfer the initial tower in the least number of steps. This work \
includes a solution of the general version of the Tower of Hanoi, along with \
animations.

In the following we will denote the number of disks by n and the number of \
pegs by p; we number the disks according to their size, denoting by f[n, p] \
the minimal number of movements needed to solve the Hanoi tower.

Note that, necessarily p > 2. If p > n then a trivial strategy is to \
distribute all n-1 top-most disks in different pegs and then pile them back \
up on top of the final peg, that is, f(n, p) = 2n - 1 in this case. \
Similarly, we obtain f(n, n) = 2n +1.\
\>", "Abstract"]
}, Open  ]],

Cell[BoxData[
    \(Off[General::"\<spell\>", General::"\<spell1\>"]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["The Case p=3", "Section"],

Cell["\<\
An explicit description of the disk that has to be moved at each step in the \
solution for the case p = 3 can easily be given:\
\>", "Text"],

Cell[BoxData[{
    \(h3[1] := {1}\), "\[IndentingNewLine]", 
    \(h3[n_] := \(h3[n] = Join[h3[n - 1], {n}, h3[n - 1]]\)\)}], "Input",
  CellLabel->"In[180]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(h3[4]\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    \({1, 2, 1, 3, 1, 2, 1, 4, 1, 2, 1, 3, 1, 2, 1}\)], "Output",
  CellLabel->"Out[182]="]
}, Open  ]],

Cell["The explicit moves needed to solve this case are:", "Text"],

Cell[BoxData[{
    \(hanoi3[1, i_, j_] := {{i, j}}\), "\n", 
    \(\(\(hanoi3[n_, i_, j_] := 
      Join[hanoi3[n - 1, i, 6 - i - j], {{i, j}}, 
        hanoi3[n - 1, 6 - i - j, j]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(disp[t_, {i_, j_}] := 
      Module[{q = t, d}, \[IndentingNewLine]d = 
          First[q\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]\
; \[IndentingNewLine]q\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\
\)\) = Rest[
            q\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)]; \
\[IndentingNewLine]q\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\
\) = Prepend[q\_\(\(\[LeftDoubleBracket]\)\(j\)\(\[RightDoubleBracket]\)\), 
            d]; \[IndentingNewLine]q]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(towers[n_] := 
      FoldList[disp, {Range[n], {}, {}}, hanoi3[n, 1, 3]]\)}], "Input",
  CellLabel->"In[187]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(towers[4] // MatrixForm\)], "Input",
  CellLabel->"In[191]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 2, 3, 4}\), \({}\), \({}\)},
            {\({2, 3, 4}\), \({1}\), \({}\)},
            {\({3, 4}\), \({1}\), \({2}\)},
            {\({3, 4}\), \({}\), \({1, 2}\)},
            {\({4}\), \({3}\), \({1, 2}\)},
            {\({1, 4}\), \({3}\), \({2}\)},
            {\({1, 4}\), \({2, 3}\), \({}\)},
            {\({4}\), \({1, 2, 3}\), \({}\)},
            {\({}\), \({1, 2, 3}\), \({4}\)},
            {\({}\), \({2, 3}\), \({1, 4}\)},
            {\({2}\), \({3}\), \({1, 4}\)},
            {\({1, 2}\), \({3}\), \({4}\)},
            {\({1, 2}\), \({}\), \({3, 4}\)},
            {\({2}\), \({1}\), \({3, 4}\)},
            {\({}\), \({1}\), \({2, 3, 4}\)},
            {\({}\), \({}\), \({1, 2, 3, 4}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[191]//MatrixForm="]
}, Open  ]],

Cell["The corresponding animation is generated as follows:", "Text"],

Cell[BoxData[{
    \(h[n_, li_] := 
      Module[{y = \(-0.5\)}, \[IndentingNewLine]Graphics[{{RGBColor[1, 0, 0], 
              Rectangle[{\(-0.2\), 0}, {0.2, n/2 + 0.5}]}, 
            Map[\((y = y + 0.5; Rectangle[{\(-#\), y}, {#, y + 0.5}])\) &, 
              Reverse[li]]}, PlotRange \[Rule] {{\(-n\), n}, {0, \ n}}, 
          AspectRatio \[Rule] 
            Automatic]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(showPattern[{a_, b_, c_}] := 
      Module[{n = Length[Flatten[{a, b, c}]]}, \(Show[
            GraphicsArray[{h[n, a], h[n, b], h[n, c]}]];\)]\)}], "Input",
  CellLabel->"In[124]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FIRST ANIMATION: Transferring a tower of 4 disks using 3 pegs (double click \
to see)\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(showPattern[#] &\) /@ towers[4];\)\)], "Input",
  CellLabel->"In[128]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
.25 .125 m
.25 .1875 L
.75 .1875 L
.75 .125 L
F
.375 .1875 m
.375 .25 L
.625 .25 L
.625 .1875 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD00000300oooo103o001H0?ooo`@0o`00
<`3oool000T0ooooE000000`0?ooo`@0o`00F03oool40?l003<0oooo00090?oooe@00000<03oool4
0?l005P0oooo103o000c0?ooo`002@3ooomD00000300oooo103o001H0?ooo`@0o`00<`3oool000T0
ooooE000000`0?ooo`@0o`00F03oool40?l003<0oooo000C0?ooocl00000>`3oool40?l005P0oooo
103o000c0?ooo`004`3ooolo000003/0oooo103o001H0?ooo`@0o`00<`3oool001<0oooo?`00000k
0?ooo`@0o`00F03oool40?l003<0oooo000C0?ooocl00000>`3oool40?l005P0oooo103o000c0?oo
o`004`3ooolo000003/0oooo103o001H0?ooo`@0o`00<`3oool001h0oooo:P0000150?ooo`@0o`00
F03oool40?l003<0oooo000N0?ooobX00000A@3oool40?l005P0oooo103o000c0?ooo`007P3ooolZ
000004D0oooo103o001H0?ooo`@0o`00<`3oool001h0oooo:P0000150?ooo`@0o`00F03oool40?l0
03<0oooo000N0?ooobX00000A@3oool40?l005P0oooo103o000c0?ooo`00:03ooolE00000500oooo
103o001H0?ooo`@0o`00<`3oool002P0oooo5@00001@0?ooo`@0o`00F03oool40?l003<0oooo000X
0?oooaD00000D03oool40?l005P0oooo103o000c0?ooo`00:03ooolE00000500oooo103o001H0?oo
o`@0o`00<`3oool002P0oooo5@00001@0?ooo`@0o`00F03oool40?l003<0oooo000X0?oooaD00000
D03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
.25 .125 m
.25 .1875 L
.75 .1875 L
.75 .125 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.375 0 m
.375 .0625 L
.625 .0625 L
.625 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD000002L0oooo5@00001@0?ooo`@0o`00
<`3oool000T0ooooE000000W0?oooaD00000D03oool40?l003<0oooo00090?oooe@000009`3ooolE
00000500oooo103o000c0?ooo`002@3ooomD000002L0oooo5@00001@0?ooo`@0o`00<`3oool000T0
ooooE000000W0?oooaD00000D03oool40?l003<0oooo000C0?ooocl00000>`3oool40?l005P0oooo
103o000c0?ooo`004`3ooolo000003/0oooo103o001H0?ooo`@0o`00<`3oool001<0oooo?`00000k
0?ooo`@0o`00F03oool40?l003<0oooo000C0?ooocl00000>`3oool40?l005P0oooo103o000c0?oo
o`004`3ooolo000003/0oooo103o001H0?ooo`@0o`00<`3oool001h0oooo:P0000150?ooo`@0o`00
F03oool40?l003<0oooo000N0?ooobX00000A@3oool40?l005P0oooo103o000c0?ooo`007P3ooolZ
000004D0oooo103o001H0?ooo`@0o`00<`3oool001h0oooo:P0000150?ooo`@0o`00F03oool40?l0
03<0oooo000N0?ooobX00000A@3oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.375 0 m
.375 .0625 L
.625 .0625 L
.625 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD000002L0oooo5@00000m0?ooobX00000
803oool000T0ooooE000000W0?oooaD00000?@3ooolZ00000200oooo00090?oooe@000009`3ooolE
000003d0oooo:P00000P0?ooo`002@3ooomD000002L0oooo5@00000m0?ooobX00000803oool000T0
ooooE000000W0?oooaD00000?@3ooolZ00000200oooo000C0?ooocl00000>`3oool40?l005P0oooo
103o000c0?ooo`004`3ooolo000003/0oooo103o001H0?ooo`@0o`00<`3oool001<0oooo?`00000k
0?ooo`@0o`00F03oool40?l003<0oooo000C0?ooocl00000>`3oool40?l005P0oooo103o000c0?oo
o`004`3ooolo000003/0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD00000300oooo103o00150?ooobX00000
803oool000T0ooooE000000`0?ooo`@0o`00A@3ooolZ00000200oooo00090?oooe@00000<03oool4
0?l004D0oooo:P00000P0?ooo`002@3ooomD00000300oooo103o00150?ooobX00000803oool000T0
ooooE000000`0?ooo`@0o`00A@3ooolZ00000200oooo000C0?ooocl00000>`3oool40?l00500oooo
5@00000Z0?ooo`004`3ooolo000003/0oooo103o001@0?oooaD00000:P3oool001<0oooo?`00000k
0?ooo`@0o`00D03ooolE000002X0oooo000C0?ooocl00000>`3oool40?l00500oooo5@00000Z0?oo
o`004`3ooolo000003/0oooo103o001@0?oooaD00000:P3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD000001<0oooo?P00000X0?ooobX00000
803oool000T0ooooE000000C0?oooch00000:03ooolZ00000200oooo00090?oooe@000004`3oooln
000002P0oooo:P00000P0?ooo`002@3ooomD000001<0oooo?P00000X0?ooobX00000803oool000T0
ooooE000000C0?oooch00000:03ooolZ00000200oooo000a0?ooo`@0o`00F03oool40?l00500oooo
5@00000Z0?ooo`00<@3oool40?l005P0oooo103o001@0?oooaD00000:P3oool00340oooo103o001H
0?ooo`@0o`00D03ooolE000002X0oooo000a0?ooo`@0o`00F03oool40?l00500oooo5@00000Z0?oo
o`00<@3oool40?l005P0oooo103o001@0?oooaD00000:P3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD000001<0oooo?P00000X0?ooobX00000
803oool000T0ooooE000000C0?oooch00000:03ooolZ00000200oooo00090?oooe@000004`3oooln
000002P0oooo:P00000P0?ooo`002@3ooomD000001<0oooo?P00000X0?ooobX00000803oool000T0
ooooE000000C0?oooch00000:03ooolZ00000200oooo000X0?oooaD00000D03oool40?l005P0oooo
103o000c0?ooo`00:03ooolE00000500oooo103o001H0?ooo`@0o`00<`3oool002P0oooo5@00001@
0?ooo`@0o`00F03oool40?l003<0oooo000X0?oooaD00000D03oool40?l005P0oooo103o000c0?oo
o`00:03ooolE00000500oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
.25 .0625 m
.25 .125 L
.75 .125 L
.75 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD000001<0oooo?P00000k0?ooo`@0o`00
<`3oool000T0ooooE000000C0?oooch00000>`3oool40?l003<0oooo00090?oooe@000004`3oooln
000003/0oooo103o000c0?ooo`002@3ooomD000001<0oooo?P00000k0?ooo`@0o`00<`3oool000T0
ooooE000000C0?oooch00000>`3oool40?l003<0oooo000X0?oooaD00000?@3ooolZ000004D0oooo
103o000c0?ooo`00:03ooolE000003d0oooo:P0000150?ooo`@0o`00<`3oool002P0oooo5@00000m
0?ooobX00000A@3oool40?l003<0oooo000X0?oooaD00000?@3ooolZ000004D0oooo103o000c0?oo
o`00:03ooolE000003d0oooo:P0000150?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
.25 .0625 m
.25 .125 L
.75 .125 L
.75 .0625 L
F
.375 .125 m
.375 .1875 L
.625 .1875 L
.625 .125 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002@3ooomD000001<0oooo?P00000k0?ooo`@0o`00
<`3oool000T0ooooE000000C0?oooch00000>`3oool40?l003<0oooo00090?oooe@000004`3oooln
000003/0oooo103o000c0?ooo`002@3ooomD000001<0oooo?P00000k0?ooo`@0o`00<`3oool000T0
ooooE000000C0?oooch00000>`3oool40?l003<0oooo000a0?ooo`@0o`00A@3ooolZ000004D0oooo
103o000c0?ooo`00<@3oool40?l004D0oooo:P0000150?ooo`@0o`00<`3oool00340oooo103o0015
0?ooobX00000A@3oool40?l003<0oooo000a0?ooo`@0o`00A@3ooolZ000004D0oooo103o000c0?oo
o`00<@3oool40?l004D0oooo:P0000150?ooo`@0o`00<`3oool00340oooo103o001?0?oooaD00000
D03oool40?l003<0oooo000a0?ooo`@0o`00C`3ooolE00000500oooo103o000c0?ooo`00<@3oool4
0?l004l0oooo5@00001@0?ooo`@0o`00<`3oool00340oooo103o001?0?oooaD00000D03oool40?l0
03<0oooo000a0?ooo`@0o`00C`3ooolE00000500oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
.25 .0625 m
.25 .125 L
.75 .125 L
.75 .0625 L
F
.375 .125 m
.375 .1875 L
.625 .1875 L
.625 .125 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool40?l003/0oooo?P00000C0?oooe@00000
2`3oool00340oooo103o000k0?oooch000004`3ooomD000000/0oooo000a0?ooo`@0o`00>`3oooln
000001<0ooooE000000;0?ooo`00<@3oool40?l003/0oooo?P00000C0?oooe@000002`3oool00340
oooo103o000k0?oooch000004`3ooomD000000/0oooo000a0?ooo`@0o`00A@3ooolZ000004D0oooo
103o000c0?ooo`00<@3oool40?l004D0oooo:P0000150?ooo`@0o`00<`3oool00340oooo103o0015
0?ooobX00000A@3oool40?l003<0oooo000a0?ooo`@0o`00A@3ooolZ000004D0oooo103o000c0?oo
o`00<@3oool40?l004D0oooo:P0000150?ooo`@0o`00<`3oool00340oooo103o001?0?oooaD00000
D03oool40?l003<0oooo000a0?ooo`@0o`00C`3ooolE00000500oooo103o000c0?ooo`00<@3oool4
0?l004l0oooo5@00001@0?ooo`@0o`00<`3oool00340oooo103o001?0?oooaD00000D03oool40?l0
03<0oooo000a0?ooo`@0o`00C`3ooolE00000500oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
.25 .0625 m
.25 .125 L
.75 .125 L
.75 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool40?l003/0oooo?P00000C0?oooe@00000
2`3oool00340oooo103o000k0?oooch000004`3ooomD000000/0oooo000a0?ooo`@0o`00>`3oooln
000001<0ooooE000000;0?ooo`00<@3oool40?l003/0oooo?P00000C0?oooe@000002`3oool00340
oooo103o000k0?oooch000004`3ooomD000000/0oooo000a0?ooo`@0o`00A@3ooolZ000003d0oooo
5@00000Z0?ooo`00<@3oool40?l004D0oooo:P00000m0?oooaD00000:P3oool00340oooo103o0015
0?ooobX00000?@3ooolE000002X0oooo000a0?ooo`@0o`00A@3ooolZ000003d0oooo5@00000Z0?oo
o`00<@3oool40?l004D0oooo:P00000m0?oooaD00000:P3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007P3ooolZ000002P0oooo?P00000C0?oooe@00000
2`3oool001h0oooo:P00000X0?oooch000004`3ooomD000000/0oooo000N0?ooobX00000:03oooln
000001<0ooooE000000;0?ooo`007P3ooolZ000002P0oooo?P00000C0?oooe@000002`3oool001h0
oooo:P00000X0?oooch000004`3ooomD000000/0oooo000a0?ooo`@0o`00F03oool40?l00500oooo
5@00000Z0?ooo`00<@3oool40?l005P0oooo103o001@0?oooaD00000:P3oool00340oooo103o001H
0?ooo`@0o`00D03ooolE000002X0oooo000a0?ooo`@0o`00F03oool40?l00500oooo5@00000Z0?oo
o`00<@3oool40?l005P0oooo103o001@0?oooaD00000:P3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.125 0 m
.125 .0625 L
.875 .0625 L
.875 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007P3ooolZ000002P0oooo?P00000C0?oooe@00000
2`3oool001h0oooo:P00000X0?oooch000004`3ooomD000000/0oooo000N0?ooobX00000:03oooln
000001<0ooooE000000;0?ooo`007P3ooolZ000002P0oooo?P00000C0?oooe@000002`3oool001h0
oooo:P00000X0?oooch000004`3ooomD000000/0oooo000X0?oooaD00000D03oool40?l005P0oooo
103o000c0?ooo`00:03ooolE00000500oooo103o001H0?ooo`@0o`00<`3oool002P0oooo5@00001@
0?ooo`@0o`00F03oool40?l003<0oooo000X0?oooaD00000D03oool40?l005P0oooo103o000c0?oo
o`00:03ooolE00000500oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
.375 .0625 m
.375 .125 L
.625 .125 L
.625 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007P3ooolZ000004D0oooo103o000`0?oooe@00000
2`3oool001h0oooo:P0000150?ooo`@0o`00<03ooomD000000/0oooo000N0?ooobX00000A@3oool4
0?l00300ooooE000000;0?ooo`007P3ooolZ000004D0oooo103o000`0?oooe@000002`3oool001h0
oooo:P0000150?ooo`@0o`00<03ooomD000000/0oooo000X0?oooaD00000D03oool40?l003/0oooo
?`00000E0?ooo`00:03ooolE00000500oooo103o000k0?ooocl000005@3oool002P0oooo5@00001@
0?ooo`@0o`00>`3ooolo000001D0oooo000X0?oooaD00000D03oool40?l003/0oooo?`00000E0?oo
o`00:03ooolE00000500oooo103o000k0?ooocl000005@3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.25 0 m
.25 .0625 L
.75 .0625 L
.75 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.375 0 m
.375 .0625 L
.625 .0625 L
.625 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007P3ooolZ000003`0oooo5@00000X0?oooe@00000
2`3oool001h0oooo:P00000l0?oooaD00000:03ooomD000000/0oooo000N0?ooobX00000?03ooolE
000002P0ooooE000000;0?ooo`007P3ooolZ000003`0oooo5@00000X0?oooe@000002`3oool001h0
oooo:P00000l0?oooaD00000:03ooomD000000/0oooo000a0?ooo`@0o`00F03oool40?l003/0oooo
?`00000E0?ooo`00<@3oool40?l005P0oooo103o000k0?ooocl000005@3oool00340oooo103o001H
0?ooo`@0o`00>`3ooolo000001D0oooo000a0?ooo`@0o`00F03oool40?l003/0oooo?`00000E0?oo
o`00<@3oool40?l005P0oooo103o000k0?ooocl000005@3oool00340oooo103o001H0?ooo`@0o`00
F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool4
0?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l0
03<0oooo000a0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
.375 0 m
.375 .0625 L
.625 .0625 L
.625 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
.25 .125 m
.25 .1875 L
.75 .1875 L
.75 .125 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool40?l004l0oooo5@00000X0?oooe@00000
2`3oool00340oooo103o001?0?oooaD00000:03ooomD000000/0oooo000a0?ooo`@0o`00C`3ooolE
000002P0ooooE000000;0?ooo`00<@3oool40?l004l0oooo5@00000X0?oooe@000002`3oool00340
oooo103o001?0?oooaD00000:03ooomD000000/0oooo000a0?ooo`@0o`00F03oool40?l003/0oooo
?`00000E0?ooo`00<@3oool40?l005P0oooo103o000k0?ooocl000005@3oool00340oooo103o001H
0?ooo`@0o`00>`3ooolo000001D0oooo000a0?ooo`@0o`00F03oool40?l003/0oooo?`00000E0?oo
o`00<@3oool40?l005P0oooo103o000k0?ooocl000005@3oool00340oooo103o001H0?ooo`@0o`00
A@3ooolZ00000200oooo000a0?ooo`@0o`00F03oool40?l004D0oooo:P00000P0?ooo`00<@3oool4
0?l005P0oooo103o00150?ooobX00000803oool00340oooo103o001H0?ooo`@0o`00A@3ooolZ0000
0200oooo000a0?ooo`@0o`00F03oool40?l004D0oooo:P00000P0?ooo`00<@3oool40?l005P0oooo
103o001H0?ooo`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a
0?ooo`@0o`00F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?oo
o`@0o`00<`3oool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00
F03oool40?l005P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00372024 0.31746 [
[ 0 0 0 0 ]
[ 1 .15625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .15625 L
0 .15625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00372024 0.321429 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00372024 0.64881 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00372024 0.97619 0.15253 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0 0.125 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.475 0 m
.475 .3125 L
.525 .3125 L
.525 0 L
F
0 g
0 0 m
0 .0625 L
1 .0625 L
1 0 L
F
.125 .0625 m
.125 .125 L
.875 .125 L
.875 .0625 L
F
.25 .125 m
.25 .1875 L
.75 .1875 L
.75 .125 L
F
.375 .1875 m
.375 .25 L
.625 .25 L
.625 .1875 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 45},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000;B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool40?l005P0oooo103o000`0?oooe@00000
2`3oool00340oooo103o001H0?ooo`@0o`00<03ooomD000000/0oooo000a0?ooo`@0o`00F03oool4
0?l00300ooooE000000;0?ooo`00<@3oool40?l005P0oooo103o000`0?oooe@000002`3oool00340
oooo103o001H0?ooo`@0o`00<03ooomD000000/0oooo000a0?ooo`@0o`00F03oool40?l003/0oooo
?`00000E0?ooo`00<@3oool40?l005P0oooo103o000k0?ooocl000005@3oool00340oooo103o001H
0?ooo`@0o`00>`3ooolo000001D0oooo000a0?ooo`@0o`00F03oool40?l003/0oooo?`00000E0?oo
o`00<@3oool40?l005P0oooo103o000k0?ooocl000005@3oool00340oooo103o001H0?ooo`@0o`00
A@3ooolZ00000200oooo000a0?ooo`@0o`00F03oool40?l004D0oooo:P00000P0?ooo`00<@3oool4
0?l005P0oooo103o00150?ooobX00000803oool00340oooo103o001H0?ooo`@0o`00A@3ooolZ0000
0200oooo000a0?ooo`@0o`00F03oool40?l004D0oooo:P00000P0?ooo`00<@3oool40?l005P0oooo
103o001@0?oooaD00000:P3oool00340oooo103o001H0?ooo`@0o`00D03ooolE000002X0oooo000a
0?ooo`@0o`00F03oool40?l00500oooo5@00000Z0?ooo`00<@3oool40?l005P0oooo103o001@0?oo
oaD00000:P3oool00340oooo103o001H0?ooo`@0o`00D03ooolE000002X0oooo000a0?ooo`@0o`00
F03oool40?l00500oooo5@00000Z0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3o
ool00340oooo103o001H0?ooo`@0o`00F03oool40?l003<0oooo000a0?ooo`@0o`00F03oool40?l0
05P0oooo103o000c0?ooo`00<@3oool40?l005P0oooo103o001H0?ooo`@0o`00<`3oool00340oooo
103o001H0?ooo`@0o`00F03oool40?l003<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {44, 0}} -> {-0.105218, -0.0117212, 0.0111862, \
0.0111862}, {{9.375, 93.1875}, {42.9375, 1}} -> {-4.8949, -0.102929, \
0.0954521, 0.0954521}, {{101.563, 185.375}, {42.9375, 1}} -> {-13.6944, \
-0.102929, 0.0954521, 0.0954521}, {{193.75, 277.563}, {42.9375, 1}} -> \
{-22.4939, -0.102929, 0.0954521, 0.0954521}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Case p=4", "Section"],

Cell["\<\
The number of moves for the case p = 4 can be subordinated to those for the \
case p=3\
\>", "Text"],

Cell[BoxData[{
    \(f[1, 4] := 1\), "\[IndentingNewLine]", 
    \(f[2, 4] := 3\), "\[IndentingNewLine]", 
    \(f[n_, 4] := \(f[n, 4] = 
        Min[Table[
            2  f[a, 4] + 2\^\(n - a\) - 
              1, {a, \[LeftFloor]n\/2\[RightFloor]}]]\)\)}], "Input",
  CellLabel->"In[101]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[f[n, 4], {n, 20}]\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \({1, 3, 5, 9, 13, 17, 25, 33, 49, 57, 89, 97, 161, 177, 305, 321, 577, 
      609, 1121, 1137}\)], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell["In general:", "Text"],

Cell[BoxData[{
    \(\(\(Clear[f]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(f[n_, 3] := \(f[n, 3] = 2\^n - 1\)\), "\[IndentingNewLine]", 
    \(f[n_, n_] := \(f[n, n] = 2  n + 1\)\), "\[IndentingNewLine]", 
    \(f[n_, m_] := \(f[n, m] = 
        If[n < m, 2  n - 1, 2 \((f[n - m + 2, m] + m)\) - 5]\)\)}], "Input",
  CellLabel->"In[105]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[f[n, 5], {n, 20}]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \({1, 3, 5, 7, 11, 15, 19, 27, 35, 43, 59, 75, 91, 123, 155, 187, 251, 
      315, 379, 507}\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell[TextData[{
  "In order to obtain explicit moves for this case we design function ",
  StyleBox["hanoi4[n]",
    FontSlant->"Italic"],
  ",  which computes a triad {a, b, c}. The strategy is thus: starting from \
the pattern {n, 0, 0, 0}, (which means we have initially the pile of the n \
disks in the first of four pegs and none in the others) we want to finish \
with the pattern {0, 0, 0, n}, following the rules of the Tower of Hanoi. The \
values computed by ",
  StyleBox["hanoi4[n]",
    FontSlant->"Italic"],
  " are then used as follows: we move the first a disks to the second peg, \
then the next b disks to the third peg, then disk n from peg 1 to peg 4, then \
the disks in peg 3 to peg 4 and finally the disks on peg 2 to peg 4.  The \
total number of moves needed is computed at variable c."
}], "Text"],

Cell[BoxData[{
    \(Clear[hanoi3]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(hanoi3[n_] := {n - 1, 
        2\^n - 1}\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(hanoi4[1] = {0, 0, 1};\)\), "\[IndentingNewLine]", 
    \(\(hanoi4[2] = {1, 0, 3};\)\), "\[IndentingNewLine]", 
    \(hanoi4[n_] := \(hanoi4[n] = 
        Module[{a, t}, \[IndentingNewLine]t = 
            Table[{a, n - a - 1, 
                2 \((Last[hanoi4[a]] + Last[hanoi3[n - a - 1]])\) + 1}, {a, 
                n - 1}]; \[IndentingNewLine]First[
            Sort[t, Last[#2] > Last[#1] &]]]\)\)}], "Input",
  CellLabel->"In[145]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[hanoi4[n], {n, 20}]\)], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \({{0, 0, 1}, {1, 0, 3}, {1, 1, 5}, {2, 1, 9}, {3, 1, 13}, {3, 2, 
        17}, {4, 2, 25}, {5, 2, 33}, {6, 2, 41}, {6, 3, 49}, {7, 3, 65}, {8, 
        3, 81}, {9, 3, 97}, {10, 3, 113}, {10, 4, 129}, {11, 4, 161}, {12, 4, 
        193}, {13, 4, 225}, {14, 4, 257}, {15, 4, 289}}\)], "Output",
  CellLabel->"Out[150]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[First[hanoi4[n]], {n, 50}]\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \({0, 1, 1, 2, 3, 3, 4, 5, 6, 6, 7, 8, 9, 10, 10, 11, 12, 13, 14, 15, 15, 
      16, 17, 18, 19, 20, 21, 21, 22, 23, 24, 25, 26, 27, 28, 28, 29, 30, 31, 
      32, 33, 34, 35, 36, 36, 37, 38, 39, 40, 41}\)], "Output",
  CellLabel->"Out[151]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      n - 1 - \[LeftFloor]\(\@\(8  n + 1\) - 3\)\/2\[RightFloor], {n, 
        50}]\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \({0, 1, 1, 2, 3, 3, 4, 5, 6, 6, 7, 8, 9, 10, 10, 11, 12, 13, 14, 15, 15, 
      16, 17, 18, 19, 20, 21, 21, 22, 23, 24, 25, 26, 27, 28, 28, 29, 30, 31, 
      32, 33, 34, 35, 36, 36, 37, 38, 39, 40, 41}\)], "Output",
  CellLabel->"Out[152]="]
}, Open  ]],

Cell["\<\
The application of this idea to the case p = 5 allows us to write:\
\>", "Text"],

Cell[BoxData[{
    \(\(hanoi5[1] = {0, 0, 0, 1};\)\), "\[IndentingNewLine]", 
    \(\(hanoi5[2] = {1, 0, 0, 3};\)\), "\[IndentingNewLine]", 
    \(\(hanoi5[3] = {1, 1, 0, 5};\)\), "\[IndentingNewLine]", 
    \(hanoi5[n_] := \(hanoi5[n] = 
        Module[{a, b, t}, \[IndentingNewLine]t = 
            Flatten[Table[{a, b, n - 1 - a - b, 
                  2 \((Last[hanoi5[a]] + Last[hanoi4[b]] + 
                          Last[hanoi3[n - 1 - a - b]])\) + 1}, {a, 
                  n - 2}, {b, n - 1 - a}], 1]; \[IndentingNewLine]First[
            Sort[t, Last[#2] > Last[#1] &]]]\)\)}], "Input",
  CellLabel->"In[153]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[hanoi5[n], {n, 20}]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \({{0, 0, 0, 1}, {1, 0, 0, 3}, {1, 1, 0, 5}, {1, 1, 1, 7}, {2, 1, 1, 
        11}, {3, 1, 1, 15}, {4, 1, 1, 19}, {4, 2, 1, 23}, {4, 3, 1, 27}, {4, 
        3, 2, 31}, {5, 3, 2, 39}, {6, 3, 2, 47}, {7, 3, 2, 55}, {8, 3, 2, 
        63}, {9, 3, 2, 71}, {10, 3, 2, 79}, {10, 4, 2, 87}, {10, 5, 2, 
        95}, {10, 6, 2, 103}, {10, 6, 3, 111}}\)], "Output",
  CellLabel->"Out[158]="]
}, Open  ]],

Cell[TextData[{
  "The full generalization will require function ",
  StyleBox["sum",
    FontSlant->"Italic"],
  " computing all i-tuples with positive integers adding up to s. There are \
",
  StyleBox["Binomial[s - 1, i - 1]",
    FontSlant->"Italic"],
  " of them."
}], "Text"],

Cell[BoxData[{
    \(sums[s_, 
        i_] := {}\  /; \ \((s < i)\) || \((i == 
              0)\)\), "\[IndentingNewLine]", 
    \(sums[s_, s_] := {Table[1, {s}]}\), "\[IndentingNewLine]", 
    \(sums[s_, 1] := {{s}}\), "\[IndentingNewLine]", 
    \(sums[s_, i_] := 
      Module[{d}, \[IndentingNewLine]Flatten[
          Table[Map[Join[{d}, #] &, sums[s - d, i - 1]], {d, s - i + 1}], 
          1]]\)}], "Input",
  CellLabel->"In[171]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sums[7, 3]\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    \({{1, 1, 5}, {1, 2, 4}, {1, 3, 3}, {1, 4, 2}, {1, 5, 1}, {2, 1, 4}, {2, 
        2, 3}, {2, 3, 2}, {2, 4, 1}, {3, 1, 3}, {3, 2, 2}, {3, 3, 1}, {4, 1, 
        2}, {4, 2, 1}, {5, 1, 1}}\)], "Output",
  CellLabel->"Out[170]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[sums[11, 4]] \[Equal] Binomial[10, 3]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[BoxData[{
    \(hanoiP[n_, p_] := 
      Join[Table[1, {n - 1}], Table[0, {p - n - 1}], {2  n - 1}]\  /; \ 
        n < p - 1\), "\[IndentingNewLine]", 
    \(hanoiP[n_, p_] := \(hanoiP[n, p] = 
        Module[{v, t}, \[IndentingNewLine]t = 
            sums[n - 1, p - 2]; \[IndentingNewLine]v = 
            Map[Join[#, {2 
                         Plus @@ 
                          Table[Last[
                              hanoiP[#\_\(\(\[LeftDoubleBracket]\)\(i\)\(\
\[RightDoubleBracket]\)\), p - i + 1]], {i, p - 2}] + 1}] &, t]; 
          First[Sort[v, Last[#2] > Last[#1] &]]]\)\)}], "Input",
  CellLabel->"In[175]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(hanoiP[20, 5]\)], "Input",
  CellLabel->"In[167]:="],

Cell[BoxData[
    \({10, 6, 3, 111}\)], "Output",
  CellLabel->"Out[167]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[hanoiP[n, p], {n, 20}, {p, 3, 8}] // MatrixForm\)], "Input",
  CellLabel->"In[177]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0, 1}\), \({0, 0, 1}\), \({0, 0, 0, 1}\), \({0, 0, 0, 0, 
                1}\), \({0, 0, 0, 0, 0, 1}\), \({0, 0, 0, 0, 0, 0, 1}\)},
            {\({1, 3}\), \({1, 0, 3}\), \({1, 0, 0, 3}\), \({1, 0, 0, 0, 
                3}\), \({1, 0, 0, 0, 0, 3}\), \({1, 0, 0, 0, 0, 0, 3}\)},
            {\({2, 7}\), \({1, 1, 5}\), \({1, 1, 0, 5}\), \({1, 1, 0, 0, 
                5}\), \({1, 1, 0, 0, 0, 5}\), \({1, 1, 0, 0, 0, 0, 5}\)},
            {\({3, 15}\), \({2, 1, 9}\), \({1, 1, 1, 7}\), \({1, 1, 1, 0, 
                7}\), \({1, 1, 1, 0, 0, 7}\), \({1, 1, 1, 0, 0, 0, 7}\)},
            {\({4, 31}\), \({3, 1, 13}\), \({2, 1, 1, 11}\), \({1, 1, 1, 1, 
                9}\), \({1, 1, 1, 1, 0, 9}\), \({1, 1, 1, 1, 0, 0, 9}\)},
            {\({5, 63}\), \({3, 2, 17}\), \({3, 1, 1, 15}\), \({2, 1, 1, 1, 
                13}\), \({1, 1, 1, 1, 1, 11}\), \({1, 1, 1, 1, 1, 0, 11}\)},
            {\({6, 127}\), \({4, 2, 25}\), \({4, 1, 1, 19}\), \({3, 1, 1, 1, 
                17}\), \({2, 1, 1, 1, 1, 15}\), \({1, 1, 1, 1, 1, 1, 13}\)},
            {\({7, 255}\), \({5, 2, 33}\), \({4, 2, 1, 23}\), \({4, 1, 1, 1, 
                21}\), \({3, 1, 1, 1, 1, 19}\), \({2, 1, 1, 1, 1, 1, 17}\)},
            {\({8, 511}\), \({6, 2, 41}\), \({4, 3, 1, 27}\), \({5, 1, 1, 1, 
                25}\), \({4, 1, 1, 1, 1, 23}\), \({3, 1, 1, 1, 1, 1, 21}\)},
            {\({9, 1023}\), \({6, 3, 49}\), \({4, 3, 2, 31}\), \({5, 2, 1, 1, 
                29}\), \({5, 1, 1, 1, 1, 27}\), \({4, 1, 1, 1, 1, 1, 25}\)},
            {\({10, 2047}\), \({7, 3, 65}\), \({5, 3, 2, 39}\), \({5, 3, 1, 
                1, 33}\), \({6, 1, 1, 1, 1, 31}\), \({5, 1, 1, 1, 1, 1, 
                29}\)},
            {\({11, 4095}\), \({8, 3, 81}\), \({6, 3, 2, 47}\), \({5, 4, 1, 
                1, 37}\), \({6, 2, 1, 1, 1, 35}\), \({6, 1, 1, 1, 1, 1, 
                33}\)},
            {\({12, 8191}\), \({9, 3, 97}\), \({7, 3, 2, 55}\), \({5, 4, 2, 
                1, 41}\), \({6, 3, 1, 1, 1, 39}\), \({7, 1, 1, 1, 1, 1, 
                37}\)},
            {\({13, 16383}\), \({10, 3, 113}\), \({8, 3, 2, 63}\), \({5, 4, 
                3, 1, 45}\), \({6, 4, 1, 1, 1, 43}\), \({7, 2, 1, 1, 1, 1, 
                41}\)},
            {\({14, 32767}\), \({10, 4, 129}\), \({9, 3, 2, 71}\), \({5, 4, 
                3, 2, 49}\), \({6, 5, 1, 1, 1, 47}\), \({7, 3, 1, 1, 1, 1, 
                45}\)},
            {\({15, 65535}\), \({11, 4, 161}\), \({10, 3, 2, 79}\), \({6, 4, 
                3, 2, 57}\), \({6, 5, 2, 1, 1, 51}\), \({7, 4, 1, 1, 1, 1, 
                49}\)},
            {\({16, 131071}\), \({12, 4, 193}\), \({10, 4, 2, 87}\), \({7, 4, 
                3, 2, 65}\), \({6, 5, 3, 1, 1, 55}\), \({7, 5, 1, 1, 1, 1, 
                53}\)},
            {\({17, 262143}\), \({13, 4, 225}\), \({10, 5, 2, 95}\), \({8, 4, 
                3, 2, 73}\), \({6, 5, 4, 1, 1, 59}\), \({7, 6, 1, 1, 1, 1, 
                57}\)},
            {\({18, 524287}\), \({14, 4, 257}\), \({10, 6, 2, 103}\), \({9, 
                4, 3, 2, 81}\), \({6, 5, 4, 2, 1, 63}\), \({7, 6, 2, 1, 1, 1, 
                61}\)},
            {\({19, 1048575}\), \({15, 4, 289}\), \({10, 6, 3, 111}\), \({10, 
                4, 3, 2, 89}\), \({6, 5, 4, 3, 1, 67}\), \({7, 6, 3, 1, 1, 1, 
                65}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[177]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Last[hanoiP[n, p]], {n, 20}, {p, 3, 8}] // MatrixForm\)], "Input",\

  CellLabel->"In[178]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1", "1"},
            {"3", "3", "3", "3", "3", "3"},
            {"7", "5", "5", "5", "5", "5"},
            {"15", "9", "7", "7", "7", "7"},
            {"31", "13", "11", "9", "9", "9"},
            {"63", "17", "15", "13", "11", "11"},
            {"127", "25", "19", "17", "15", "13"},
            {"255", "33", "23", "21", "19", "17"},
            {"511", "41", "27", "25", "23", "21"},
            {"1023", "49", "31", "29", "27", "25"},
            {"2047", "65", "39", "33", "31", "29"},
            {"4095", "81", "47", "37", "35", "33"},
            {"8191", "97", "55", "41", "39", "37"},
            {"16383", "113", "63", "45", "43", "41"},
            {"32767", "129", "71", "49", "47", "45"},
            {"65535", "161", "79", "57", "51", "49"},
            {"131071", "193", "87", "65", "55", "53"},
            {"262143", "225", "95", "73", "59", "57"},
            {"524287", "257", "103", "81", "63", "61"},
            {"1048575", "289", "111", "89", "67", "65"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[178]//MatrixForm="]
}, Open  ]],

Cell["\<\
For instance, the entry having value 25 in the above table asserts that it \
takes 25 steps to transfer a tower of 7 disks from the first to the last of \
four available pegs. It seems that hanoiP[n, n] =7 + 2(n-3) = 2n+1 and that \
hanoiP[n-1, n] = 3+2(n-2) = 2n - 1. Any column can also be obtained by using \
the following function:\
\>", "Text"],

Cell[BoxData[{
    \(Q[0, _] := 0\), "\[IndentingNewLine]", 
    \(Q[n_, k_] := \(Q[n, k] = 
        Module[{l = 0}, \[IndentingNewLine]While[
            n > Binomial[k + l, l], \(l++\)]; \[IndentingNewLine]Q[n - 1, 
              k] + 2\^l]\)\)}], "Input",
  CellLabel->"In[72]:="],

Cell["For example, the third column is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Q[n, 3], {n, 20}]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \({1, 3, 5, 7, 11, 15, 19, 23, 27, 31, 39, 47, 55, 63, 71, 79, 87, 95, 
      103, 111}\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell["Finally, the general function is:", "Text"],

Cell[BoxData[{
    \(superHanoi[{{d_}, {a_, ___, b_}}] := {d, a, 
        b}\), "\[IndentingNewLine]", 
    \(\(\(superHanoi[{tower_, pegs_}] := 
      Module[{a, pat, lp = Length[pegs], n, ans = {}, i, p, spread, 
          back}, \[IndentingNewLine]a = 
          Drop[hanoiP[Length[tower], lp], \(-1\)]; \[IndentingNewLine]pat = 
          Table[Take[
              tower, {1 + \[Sum]\+\(i = 1\)\%\(n - 1\)a\_\(\(\
\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\), \[Sum]\+\(i = 1\)\%n \
a\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)}], {n, 
              lp - 2}]; \[IndentingNewLine]spread = 
          Table[p = Drop[pegs, {2, n}]; i = Last[p]; \ 
            p\_\(\(\[LeftDoubleBracket]\)\(-1\)\(\[RightDoubleBracket]\)\) = 
              p\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\); 
            p\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\) = 
              i; {pat\_\(\(\[LeftDoubleBracket]\)\(n\)\(\[RightDoubleBracket]\
\)\), p}, {n, lp - 2}]; \[IndentingNewLine]spread = 
          Cases[spread, {{__}, _}]; \[IndentingNewLine]back = 
          Map[{First[#], 
                Join[{Last[Last[#]]}, 
                  Complement[
                    Last[#], {Last[Last[#]], Last[pegs]}], {Last[pegs]}]} &, 
            Reverse[spread]]; \[IndentingNewLine]Map[
          AppendTo[ans, superHanoi[#]] &, 
          spread]; \[IndentingNewLine]AppendTo[
          ans, {Last[tower], First[pegs], 
            Last[pegs]}]; \[IndentingNewLine]Map[
          AppendTo[ans, superHanoi[#]] &, back]; \[IndentingNewLine]Partition[
          Flatten[ans], 3]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(tow[numDisks_, numPegs_] := 
      Module[{t, 
          sH = superHanoi[{Range[numDisks], 
                Range[numPegs]}]}, \[IndentingNewLine]FoldList[\((t = #1; 
              t\_\(\(\[LeftDoubleBracket]\)\(#2\_\(\(\[LeftDoubleBracket]\)\(\
2\)\(\[RightDoubleBracket]\)\)\)\(\[RightDoubleBracket]\)\) = 
                Rest[t\_\(\(\[LeftDoubleBracket]\)\(#2\_\(\(\
\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\)\(\
\[RightDoubleBracket]\)\)]; 
              t\_\(\(\[LeftDoubleBracket]\)\(Last[#2]\)\(\[RightDoubleBracket]\
\)\) = Prepend[
                  t\_\(\(\[LeftDoubleBracket]\)\(Last[#2]\)\(\
\[RightDoubleBracket]\)\), First[#2]]; t)\) &, 
          Join[{Range[numDisks]}, Table[{}, {numPegs - 1}]], sH]]\)}], "Input",\

  CellLabel->"In[177]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[MatrixForm[tow[5, n]], {n, 3, 6}]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\({1, 2, 3, 4, 5}\), \({}\), \({}\)},
                {\({2, 3, 4, 5}\), \({}\), \({1}\)},
                {\({3, 4, 5}\), \({2}\), \({1}\)},
                {\({3, 4, 5}\), \({1, 2}\), \({}\)},
                {\({4, 5}\), \({1, 2}\), \({3}\)},
                {\({1, 4, 5}\), \({2}\), \({3}\)},
                {\({1, 4, 5}\), \({}\), \({2, 3}\)},
                {\({4, 5}\), \({}\), \({1, 2, 3}\)},
                {\({5}\), \({4}\), \({1, 2, 3}\)},
                {\({5}\), \({1, 4}\), \({2, 3}\)},
                {\({2, 5}\), \({1, 4}\), \({3}\)},
                {\({1, 2, 5}\), \({4}\), \({3}\)},
                {\({1, 2, 5}\), \({3, 4}\), \({}\)},
                {\({2, 5}\), \({3, 4}\), \({1}\)},
                {\({5}\), \({2, 3, 4}\), \({1}\)},
                {\({5}\), \({1, 2, 3, 4}\), \({}\)},
                {\({}\), \({1, 2, 3, 4}\), \({5}\)},
                {\({1}\), \({2, 3, 4}\), \({5}\)},
                {\({1}\), \({3, 4}\), \({2, 5}\)},
                {\({}\), \({3, 4}\), \({1, 2, 5}\)},
                {\({3}\), \({4}\), \({1, 2, 5}\)},
                {\({3}\), \({1, 4}\), \({2, 5}\)},
                {\({2, 3}\), \({1, 4}\), \({5}\)},
                {\({1, 2, 3}\), \({4}\), \({5}\)},
                {\({1, 2, 3}\), \({}\), \({4, 5}\)},
                {\({2, 3}\), \({}\), \({1, 4, 5}\)},
                {\({3}\), \({2}\), \({1, 4, 5}\)},
                {\({3}\), \({1, 2}\), \({4, 5}\)},
                {\({}\), \({1, 2}\), \({3, 4, 5}\)},
                {\({1}\), \({2}\), \({3, 4, 5}\)},
                {\({1}\), \({}\), \({2, 3, 4, 5}\)},
                {\({}\), \({}\), \({1, 2, 3, 4, 5}\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\({1, 2, 3, 4, 5}\), \({}\), \({}\), \({}\)},
                {\({2, 3, 4, 5}\), \({}\), \({}\), \({1}\)},
                {\({3, 4, 5}\), \({}\), \({2}\), \({1}\)},
                {\({4, 5}\), \({3}\), \({2}\), \({1}\)},
                {\({4, 5}\), \({2, 3}\), \({}\), \({1}\)},
                {\({4, 5}\), \({1, 2, 3}\), \({}\), \({}\)},
                {\({5}\), \({1, 2, 3}\), \({4}\), \({}\)},
                {\({}\), \({1, 2, 3}\), \({4}\), \({5}\)},
                {\({}\), \({1, 2, 3}\), \({}\), \({4, 5}\)},
                {\({1}\), \({2, 3}\), \({}\), \({4, 5}\)},
                {\({1}\), \({3}\), \({2}\), \({4, 5}\)},
                {\({1}\), \({}\), \({2}\), \({3, 4, 5}\)},
                {\({1}\), \({}\), \({}\), \({2, 3, 4, 5}\)},
                {\({}\), \({}\), \({}\), \({1, 2, 3, 4, 5}\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\({1, 2, 3, 4, 5}\), \({}\), \({}\), \({}\), \({}\)},
                {\({2, 3, 4, 5}\), \({}\), \({}\), \({}\), \({1}\)},
                {\({3, 4, 5}\), \({2}\), \({}\), \({}\), \({1}\)},
                {\({3, 4, 5}\), \({1, 2}\), \({}\), \({}\), \({}\)},
                {\({4, 5}\), \({1, 2}\), \({3}\), \({}\), \({}\)},
                {\({5}\), \({1, 2}\), \({3}\), \({4}\), \({}\)},
                {\({}\), \({1, 2}\), \({3}\), \({4}\), \({5}\)},
                {\({}\), \({1, 2}\), \({3}\), \({}\), \({4, 5}\)},
                {\({}\), \({1, 2}\), \({}\), \({}\), \({3, 4, 5}\)},
                {\({1}\), \({2}\), \({}\), \({}\), \({3, 4, 5}\)},
                {\({1}\), \({}\), \({}\), \({}\), \({2, 3, 4, 5}\)},
                {\({}\), \({}\), \({}\), \({}\), \({1, 2, 3, 4, 5}\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\({1, 2, 3, 4, 
                    5}\), \({}\), \({}\), \({}\), \({}\), \({}\)},
                {\({2, 3, 4, 5}\), \({1}\), \({}\), \({}\), \({}\), \({}\)},
                {\({3, 4, 5}\), \({1}\), \({2}\), \({}\), \({}\), \({}\)},
                {\({4, 5}\), \({1}\), \({2}\), \({3}\), \({}\), \({}\)},
                {\({5}\), \({1}\), \({2}\), \({3}\), \({4}\), \({}\)},
                {\({}\), \({1}\), \({2}\), \({3}\), \({4}\), \({5}\)},
                {\({}\), \({1}\), \({2}\), \({3}\), \({}\), \({4, 5}\)},
                {\({}\), \({1}\), \({2}\), \({}\), \({}\), \({3, 4, 5}\)},
                {\({}\), \({1}\), \({}\), \({}\), \({}\), \({2, 3, 4, 5}\)},
                {\({}\), \({}\), \({}\), \({}\), \({}\), \({1, 2, 3, 4, 5}\)}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output",
  CellLabel->"Out[87]="]
}, Open  ]],

Cell["The corresponding animation is generated as follows:", "Text"],

Cell[BoxData[{
    \(Clear[h]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(h[n_, p_] := 
      Module[{y = \(-0.5\)}, \[IndentingNewLine]Graphics[{{RGBColor[1, 0, 0], 
              Rectangle[{\(-0.2\), 0}, {0.2, n/2 + 0.5}]}, 
            Map[\((y = y + 0.5; Rectangle[{\(-#\), y}, {#, y + 0.5}])\) &, 
              Reverse[p]]}, PlotRange \[Rule] {{\(-n\), n}, {0, \ n}}, 
          AspectRatio \[Rule] 
            Automatic]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(showHanoi[pattern_] := 
      Module[{n = Length[Flatten[pattern]]}, \(Show[
            GraphicsArray[\(h[n, #] &\) /@ pattern]];\)]\)}], "Input",
  CellLabel->"In[88]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
SECOND ANIMATION: Transferring a tower of 5 disks using 4 pegs  (double click \
to see)\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(showHanoi[#] &\) /@ tow[5, 4];\)\)], "Input",
  CellLabel->"In[91]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
.2 .1 m
.2 .15 L
.8 .15 L
.8 .1 L
F
.3 .15 m
.3 .2 L
.7 .2 L
.7 .15 L
F
.4 .2 m
.4 .25 L
.6 .25 L
.6 .2 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`002P3oooln000002@0oooo0P3o00120?ooo`80o`00@P3oool20?l002X0
oooo000:0?oooch00000903oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool000X0oooo?P00
000T0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00403ooolb000002X0oooo0P3o0012
0?ooo`80o`00@P3oool20?l002X0oooo000@0?oooc800000:P3oool20?l00480oooo0P3o00120?oo
o`80o`00:P3oool00100oooo<P00000Z0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00
5`3ooolU00000300oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000G0?ooobD00000<03o
ool20?l00480oooo0P3o00120?ooo`80o`00:P3oool001L0oooo9@00000`0?ooo`80o`00@P3oool2
0?l00480oooo0P3o000Z0?ooo`007@3ooolH000003L0oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000M0?oooaP00000=`3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool001d0oooo
6000000g0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`008`3oool<000003d0oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000S0?ooo``00000?@3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002<0oooo3000000m0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
.2 .1 m
.2 .15 L
.8 .15 L
.8 .1 L
F
.3 .15 m
.3 .2 L
.7 .2 L
.7 .15 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`002P3oooln000002@0oooo0P3o00120?ooo`80o`00?@3oool<000002D0
oooo000:0?oooch00000903oool20?l00480oooo0P3o000m0?ooo``000009@3oool000X0oooo?P00
000T0?ooo`80o`00@P3oool20?l003d0oooo3000000U0?ooo`00403ooolb000002X0oooo0P3o0012
0?ooo`80o`00@P3oool20?l002X0oooo000@0?oooc800000:P3oool20?l00480oooo0P3o00120?oo
o`80o`00:P3oool00100oooo<P00000Z0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00
5`3ooolU00000300oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000G0?ooobD00000<03o
ool20?l00480oooo0P3o00120?ooo`80o`00:P3oool001L0oooo9@00000`0?ooo`80o`00@P3oool2
0?l00480oooo0P3o000Z0?ooo`007@3ooolH000003L0oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000M0?oooaP00000=`3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool001d0oooo
6000000g0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
.2 .1 m
.2 .15 L
.8 .15 L
.8 .1 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.3 0 m
.3 .05 L
.7 .05 L
.7 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`002P3oooln000002@0oooo0P3o000g0?oooaP00000<P3oool<000002D0
oooo000:0?oooch00000903oool20?l003L0oooo6000000b0?ooo``000009@3oool000X0oooo?P00
000T0?ooo`80o`00=`3ooolH00000380oooo3000000U0?ooo`00403ooolb000002X0oooo0P3o0012
0?ooo`80o`00@P3oool20?l002X0oooo000@0?oooc800000:P3oool20?l00480oooo0P3o00120?oo
o`80o`00:P3oool00100oooo<P00000Z0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00
5`3ooolU00000300oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000G0?ooobD00000<03o
ool20?l00480oooo0P3o00120?ooo`80o`00:P3oool001L0oooo9@00000`0?ooo`80o`00@P3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.3 0 m
.3 .05 L
.7 .05 L
.7 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`002P3oooln00000180oooo9P00000U0?oooaP00000<P3oool<000002D0
oooo000:0?oooch000004P3ooolV000002D0oooo6000000b0?ooo``000009@3oool000X0oooo?P00
000B0?ooobH000009@3ooolH00000380oooo3000000U0?ooo`00403ooolb000002X0oooo0P3o0012
0?ooo`80o`00@P3oool20?l002X0oooo000@0?oooc800000:P3oool20?l00480oooo0P3o00120?oo
o`80o`00:P3oool00100oooo<P00000Z0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00
:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3o
ool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
.3 .05 m
.3 .1 L
.7 .1 L
.7 .05 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`002P3oooln00000180oooo9P00000`0?ooo`80o`00?@3oool<000002D0
oooo000:0?oooch000004P3ooolV00000300oooo0P3o000m0?ooo``000009@3oool000X0oooo?P00
000B0?ooobH00000<03oool20?l003d0oooo3000000U0?ooo`00403ooolb000001l0oooo6000000g
0?ooo`80o`00@P3oool20?l002X0oooo000@0?oooc8000007`3ooolH000003L0oooo0P3o00120?oo
o`80o`00:P3oool00100oooo<P00000O0?oooaP00000=`3oool20?l00480oooo0P3o000Z0?ooo`00
:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3o
ool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
.3 .05 m
.3 .1 L
.7 .1 L
.7 .05 L
F
.4 .1 m
.4 .15 L
.6 .15 L
.6 .1 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`002P3oooln00000180oooo9P00000`0?ooo`80o`00@P3oool20?l002X0
oooo000:0?oooch000004P3ooolV00000300oooo0P3o00120?ooo`80o`00:P3oool000X0oooo?P00
000B0?ooobH00000<03oool20?l00480oooo0P3o000Z0?ooo`00403ooolb000001l0oooo6000000g
0?ooo`80o`00@P3oool20?l002X0oooo000@0?oooc8000007`3ooolH000003L0oooo0P3o00120?oo
o`80o`00:P3oool00100oooo<P00000O0?oooaP00000=`3oool20?l00480oooo0P3o000Z0?ooo`00
:03oool20?l003d0oooo3000000m0?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00?@3o
ool<000003d0oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o000m0?ooo``00000?@3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
.3 .05 m
.3 .1 L
.7 .1 L
.7 .05 L
F
.4 .1 m
.4 .15 L
.6 .15 L
.6 .1 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.1 0 m
.1 .05 L
.9 .05 L
.9 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`002P3oooln00000180oooo9P00000H0?oooc800000:P3oool20?l002X0
oooo000:0?oooch000004P3ooolV000001P0oooo<P00000Z0?ooo`80o`00:P3oool000X0oooo?P00
000B0?ooobH00000603ooolb000002X0oooo0P3o000Z0?ooo`00:03oool20?l003L0oooo6000000g
0?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00=`3ooolH000003L0oooo0P3o00120?oo
o`80o`00:P3oool002P0oooo0P3o000g0?oooaP00000=`3oool20?l00480oooo0P3o000Z0?ooo`00
:03oool20?l003d0oooo3000000m0?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00?@3o
ool<000003d0oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o000m0?ooo``00000?@3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
.3 .05 m
.3 .1 L
.7 .1 L
.7 .05 L
F
.4 .1 m
.4 .15 L
.6 .15 L
.6 .1 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.1 0 m
.1 .05 L
.9 .05 L
.9 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00:03oool20?l00300oooo9P00000H0?oooc800000303oooln000000`0
oooo000X0?ooo`80o`00<03ooolV000001P0oooo<P00000<0?oooch00000303oool002P0oooo0P3o
000`0?ooobH00000603ooolb000000`0oooo?P00000<0?ooo`00:03oool20?l003L0oooo6000000g
0?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00=`3ooolH000003L0oooo0P3o00120?oo
o`80o`00:P3oool002P0oooo0P3o000g0?oooaP00000=`3oool20?l00480oooo0P3o000Z0?ooo`00
:03oool20?l003d0oooo3000000m0?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00?@3o
ool<000003d0oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o000m0?ooo``00000?@3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
.3 .05 m
.3 .1 L
.7 .1 L
.7 .05 L
F
.4 .1 m
.4 .15 L
.6 .15 L
.6 .1 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00:03oool20?l00300oooo9P00000`0?ooo`80o`00903oooln000000`0
oooo000X0?ooo`80o`00<03ooolV00000300oooo0P3o000T0?oooch00000303oool002P0oooo0P3o
000`0?ooobH00000<03oool20?l002@0oooo?P00000<0?ooo`00:03oool20?l003L0oooo6000000g
0?ooo`80o`00:P3ooolb00000180oooo000X0?ooo`80o`00=`3ooolH000003L0oooo0P3o000Z0?oo
oc8000004P3oool002P0oooo0P3o000g0?oooaP00000=`3oool20?l002X0oooo<P00000B0?ooo`00
:03oool20?l003d0oooo3000000m0?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00?@3o
ool<000003d0oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o000m0?ooo``00000?@3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
.3 .05 m
.3 .1 L
.7 .1 L
.7 .05 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`008`3oool<000002/0oooo9P00000`0?ooo`80o`00903oooln000000`0
oooo000S0?ooo``00000:`3ooolV00000300oooo0P3o000T0?oooch00000303oool002<0oooo3000
000[0?ooobH00000<03oool20?l002@0oooo?P00000<0?ooo`00:03oool20?l003L0oooo6000000g
0?ooo`80o`00:P3ooolb00000180oooo000X0?ooo`80o`00=`3ooolH000003L0oooo0P3o000Z0?oo
oc8000004P3oool002P0oooo0P3o000g0?oooaP00000=`3oool20?l002X0oooo<P00000B0?ooo`00
:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3o
ool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.2 0 m
.2 .05 L
.8 .05 L
.8 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.3 0 m
.3 .05 L
.7 .05 L
.7 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`008`3oool<000002/0oooo9P00000U0?oooaP000006@3oooln000000`0
oooo000S0?ooo``00000:`3ooolV000002D0oooo6000000I0?oooch00000303oool002<0oooo3000
000[0?ooobH000009@3ooolH000001T0oooo?P00000<0?ooo`00:03oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3ooolb00000180oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
oc8000004P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo<P00000B0?ooo`00
:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3o
ool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool2
0?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.3 0 m
.3 .05 L
.7 .05 L
.7 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
.2 .1 m
.2 .15 L
.8 .15 L
.8 .1 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`008`3oool<000003d0oooo0P3o000g0?oooaP000006@3oooln000000`0
oooo000S0?ooo``00000?@3oool20?l003L0oooo6000000I0?oooch00000303oool002<0oooo3000
000m0?ooo`80o`00=`3ooolH000001T0oooo?P00000<0?ooo`00:03oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3ooolb00000180oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
oc8000004P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo<P00000B0?ooo`00
:03oool20?l00480oooo0P3o00120?ooo`80o`00<03ooolU000001T0oooo000X0?ooo`80o`00@P3o
ool20?l00480oooo0P3o000`0?ooobD000006@3oool002P0oooo0P3o00120?ooo`80o`00@P3oool2
0?l00300oooo9@00000I0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l0
02X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
.4 0 m
.4 .05 L
.6 .05 L
.6 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
.2 .1 m
.2 .15 L
.8 .15 L
.8 .1 L
F
.3 .15 m
.3 .2 L
.7 .2 L
.7 .15 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`008`3oool<000003d0oooo0P3o00120?ooo`80o`00903oooln000000`0
oooo000S0?ooo``00000?@3oool20?l00480oooo0P3o000T0?oooch00000303oool002<0oooo3000
000m0?ooo`80o`00@P3oool20?l002@0oooo?P00000<0?ooo`00:03oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3ooolb00000180oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
oc8000004P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo<P00000B0?ooo`00
:03oool20?l00480oooo0P3o00120?ooo`80o`00<03ooolU000001T0oooo000X0?ooo`80o`00@P3o
ool20?l00480oooo0P3o000`0?ooobD000006@3oool002P0oooo0P3o00120?ooo`80o`00@P3oool2
0?l00300oooo9@00000I0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00=`3ooolH0000
01l0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000g0?oooaP000007`3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l003L0oooo6000000O0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11628 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.00276855 0.238095 [
[ 0 0 0 0 ]
[ 1 .11628 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11628 L
0 .11628 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00276855 0.245293 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.00276855 0.488926 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.00276855 0.732558 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.00276855 0.97619 0.113511 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 -1.38778e-017 0.1 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
1 0 0 r
.48 0 m
.48 .3 L
.52 .3 L
.52 0 L
F
0 g
0 0 m
0 .05 L
1 .05 L
1 0 L
F
.1 .05 m
.1 .1 L
.9 .1 L
.9 .05 L
F
.2 .1 m
.2 .15 L
.8 .15 L
.8 .1 L
F
.3 .15 m
.3 .2 L
.7 .2 L
.7 .15 L
F
.4 .2 m
.4 .25 L
.6 .25 L
.6 .2 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 33.4375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00008B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00903oooln000000`0
oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000T0?oooch00000303oool002P0oooo0P3o
00120?ooo`80o`00@P3oool20?l002@0oooo?P00000<0?ooo`00:03oool20?l00480oooo0P3o0012
0?ooo`80o`00:P3ooolb00000180oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000Z0?oo
oc8000004P3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo<P00000B0?ooo`00
:03oool20?l00480oooo0P3o00120?ooo`80o`00<03ooolU000001T0oooo000X0?ooo`80o`00@P3o
ool20?l00480oooo0P3o000`0?ooobD000006@3oool002P0oooo0P3o00120?ooo`80o`00@P3oool2
0?l00300oooo9@00000I0?ooo`00:03oool20?l00480oooo0P3o00120?ooo`80o`00=`3ooolH0000
01l0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000g0?oooaP000007`3oool002P0oooo
0P3o00120?ooo`80o`00@P3oool20?l003L0oooo6000000O0?ooo`00:03oool20?l00480oooo0P3o
00120?ooo`80o`00?@3oool<000002D0oooo000X0?ooo`80o`00@P3oool20?l00480oooo0P3o000m
0?ooo``000009@3oool002P0oooo0P3o00120?ooo`80o`00@P3oool20?l003d0oooo3000000U0?oo
o`00:03oool20?l00480oooo0P3o00120?ooo`80o`00@P3oool20?l002X0oooo000X0?ooo`80o`00
@P3oool20?l00480oooo0P3o00120?ooo`80o`00:P3oool002P0oooo0P3o00120?ooo`80o`00@P3o
ool20?l00480oooo0P3o000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {32.4375, 0}} -> {-0.160544, -0.0116304, \
0.0150561, 0.0150561}, {{10.625, 72.4375}, {31.625, 0.75}} -> {-6.72578, \
-0.131605, 0.161945, 0.161945}, {{78.625, 140.375}, {31.625, 0.75}} -> \
{-17.733, -0.131605, 0.161945, 0.161945}, {{146.563, 208.375}, {31.625, \
0.75}} -> {-28.7402, -0.131605, 0.161945, 0.161945}, {{214.5, 276.313}, \
{31.625, 0.75}} -> {-39.7423, -0.131605, 0.161945, 0.161945}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 971}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{893, 827},
WindowMargins->{{Automatic, 151}, {Automatic, 32}},
ShowCellLabel->False,
Magnification->1,
StyleDefinitions -> "ArticleClassic.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 126, 2, 93, "Title"],
Cell[1905, 57, 98, 2, 41, "Author"],
Cell[2006, 61, 175, 5, 72, "Address"],
Cell[2184, 68, 210, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[2419, 78, 36, 0, 62, "SectionFirst"],
Cell[2458, 80, 332, 10, 94, "Reference"],
Cell[2793, 92, 1297, 21, 199, "Abstract"]
}, Open  ]],
Cell[4105, 116, 109, 2, 31, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4239, 122, 31, 0, 56, "Section"],
Cell[4273, 124, 151, 3, 27, "Text"],
Cell[4427, 129, 160, 3, 51, "Input"],

Cell[CellGroupData[{
Cell[4612, 136, 64, 2, 31, "Input"],
Cell[4679, 140, 105, 2, 30, "Output"]
}, Open  ]],
Cell[4799, 145, 65, 0, 27, "Text"],
Cell[4867, 147, 946, 18, 211, "Input"],

Cell[CellGroupData[{
Cell[5838, 169, 82, 2, 31, "Input"],
Cell[5923, 173, 945, 22, 266, "Output"]
}, Open  ]],
Cell[6883, 198, 68, 0, 27, "Text"],
Cell[6954, 200, 615, 11, 151, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7606, 216, 112, 3, 56, "Section"],

Cell[CellGroupData[{
Cell[7743, 223, 97, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[7865, 229, 4344, 185, 53, 2148, 153, "GraphicsData", "PostScript", \
"Graphics"],
Cell[12212, 416, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[16559, 604, 4342, 187, 53, 2146, 155, "GraphicsData", "PostScript", \
"Graphics"],
Cell[20904, 793, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[25251, 981, 4342, 187, 53, 2146, 155, "GraphicsData", "PostScript", \
"Graphics"],
Cell[29596, 1170, 4342, 187, 53, 2146, 155, "GraphicsData", "PostScript", \
"Graphics"],
Cell[33941, 1359, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[38288, 1547, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[42635, 1735, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[46982, 1923, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[51329, 2111, 4342, 187, 53, 2146, 155, "GraphicsData", "PostScript", \
"Graphics"],
Cell[55674, 2300, 4342, 187, 53, 2146, 155, "GraphicsData", "PostScript", \
"Graphics"],
Cell[60019, 2489, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[64366, 2677, 4342, 187, 53, 2146, 155, "GraphicsData", "PostScript", \
"Graphics"],
Cell[68711, 2866, 4344, 186, 53, 2148, 154, "GraphicsData", "PostScript", \
"Graphics"],
Cell[73058, 3054, 4344, 185, 53, 2148, 153, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[77463, 3246, 31, 0, 56, "Section"],
Cell[77497, 3248, 110, 3, 27, "Text"],
Cell[77610, 3253, 293, 7, 82, "Input"],

Cell[CellGroupData[{
Cell[77928, 3264, 82, 2, 31, "Input"],
Cell[78013, 3268, 153, 3, 30, "Output"]
}, Open  ]],
Cell[78181, 3274, 27, 0, 27, "Text"],
Cell[78211, 3276, 364, 7, 111, "Input"],

Cell[CellGroupData[{
Cell[78600, 3287, 82, 2, 31, "Input"],
Cell[78685, 3291, 150, 3, 30, "Output"]
}, Open  ]],
Cell[78850, 3297, 823, 15, 78, "Text"],
Cell[79676, 3314, 624, 12, 191, "Input"],

Cell[CellGroupData[{
Cell[80325, 3330, 84, 2, 31, "Input"],
Cell[80412, 3334, 337, 5, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80786, 3344, 91, 2, 31, "Input"],
Cell[80880, 3348, 261, 4, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81178, 3357, 149, 4, 53, "Input"],
Cell[81330, 3363, 261, 4, 49, "Output"]
}, Open  ]],
Cell[81606, 3370, 90, 2, 27, "Text"],
Cell[81699, 3374, 625, 11, 151, "Input"],

Cell[CellGroupData[{
Cell[82349, 3389, 84, 2, 31, "Input"],
Cell[82436, 3393, 399, 6, 68, "Output"]
}, Open  ]],
Cell[82850, 3402, 281, 9, 27, "Text"],
Cell[83134, 3413, 470, 11, 111, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[83629, 3428, 69, 2, 31, "Input"],
Cell[83701, 3432, 243, 4, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83981, 3441, 102, 2, 31, "Input"],
Cell[84086, 3445, 63, 2, 30, "Output"]
}, Open  ]],
Cell[84164, 3450, 662, 14, 111, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[84851, 3468, 72, 2, 31, "Input"],
Cell[84926, 3472, 75, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85038, 3479, 112, 2, 31, "Input"],
Cell[85153, 3483, 3510, 56, 330, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88700, 3544, 120, 3, 31, "Input"],
Cell[88823, 3549, 1237, 26, 330, "Output"]
}, Open  ]],
Cell[90075, 3578, 359, 6, 44, "Text"],
Cell[90437, 3586, 283, 6, 93, "Input"],
Cell[90723, 3594, 49, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[90797, 3598, 81, 2, 31, "Input"],
Cell[90881, 3602, 144, 3, 30, "Output"]
}, Open  ]],
Cell[91040, 3608, 49, 0, 27, "Text"],
Cell[91092, 3610, 2489, 47, 364, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[93606, 3661, 97, 2, 31, "Input"],
Cell[93706, 3665, 4898, 92, 795, "Output"]
}, Open  ]],
Cell[98619, 3760, 68, 0, 27, "Text"],
Cell[98690, 3762, 662, 12, 171, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99389, 3779, 114, 3, 56, "Section"],

Cell[CellGroupData[{
Cell[99528, 3786, 94, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[99647, 3792, 4692, 222, 42, 2593, 190, "GraphicsData", "PostScript", \
"Graphics"],
Cell[104342, 4016, 4694, 223, 42, 2595, 191, "GraphicsData", "PostScript", \
"Graphics"],
Cell[109039, 4241, 4696, 224, 42, 2597, 192, "GraphicsData", "PostScript", \
"Graphics"],
Cell[113738, 4467, 4698, 225, 42, 2599, 193, "GraphicsData", "PostScript", \
"Graphics"],
Cell[118439, 4694, 4696, 224, 42, 2597, 192, "GraphicsData", "PostScript", \
"Graphics"],
Cell[123138, 4920, 4694, 223, 42, 2595, 191, "GraphicsData", "PostScript", \
"Graphics"],
Cell[127835, 5145, 4696, 224, 42, 2597, 192, "GraphicsData", "PostScript", \
"Graphics"],
Cell[132534, 5371, 4696, 224, 42, 2597, 192, "GraphicsData", "PostScript", \
"Graphics"],
Cell[137233, 5597, 4694, 223, 42, 2595, 191, "GraphicsData", "PostScript", \
"Graphics"],
Cell[141930, 5822, 4696, 224, 42, 2597, 192, "GraphicsData", "PostScript", \
"Graphics"],
Cell[146629, 6048, 4698, 225, 42, 2599, 193, "GraphicsData", "PostScript", \
"Graphics"],
Cell[151330, 6275, 4696, 224, 42, 2597, 192, "GraphicsData", "PostScript", \
"Graphics"],
Cell[156029, 6501, 4694, 223, 42, 2595, 191, "GraphicsData", "PostScript", \
"Graphics"],
Cell[160726, 6726, 4692, 222, 42, 2593, 190, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

